@@ -296,10 +296,8 @@ static Bool LoadPYOtherDict(void)
             fread(&iIndex, sizeof(uint), 1, fp);
             fread(&iLen, sizeof(uint), 1, fp);
             /* data is bad, break */
-            if(i<0 || i>=iCounter || j<0 || j>=iCounter || k<0 || k>=iCounter)
-                break;
-            if (i < iPYFACount) {
-                if (j < PYFAList[i].iBase) {
+            if (i>=0 && i < iPYFACount) {
+                if (j>=0 && j < PYFAList[i].iBase) {
                     if (k < PYFAList[i].pyBase[j].iPhrase) {
                         if (k >= 0) {
                             PYFAList[i].pyBase[j].phrase[k].iIndex = iIndex;
